Module proxy

Module proxy 

Structs

ProxyRequest
Raw request data forwarded to the default Responses upstream endpoint.
ProxyResponse
ProxyState

Enums

ProxyAuth
Authentication fallback used when proxying a request to an upstream API.
ProxyBody

Functions

error_response
error_response_for_auth
proxy_get
Proxy a GET request to an arbitrary upstream path.
proxy_request
Proxy a request to the default /v1/responses upstream endpoint.
proxy_request_with_path
Proxy a raw request to a selected upstream path.