Structs
Enums
Traits
- Gateway
Executor - Extension of
ToolHandlerfor tool types that are executed by the gateway. - Tool
Handler - Trait implemented by every tool type — client-owned and gateway-owned alike.
ToolHandler for tool types that are executed by the gateway.