HTTP transport layer for LLM backend communication.
Handles sending requests, reading streaming chunks, and mapping network
and HTTP errors to ExecutorError.
Functions
- call_
inference - Step 2 — Call the LLM inference backend; yields raw SSE lines (
data: …).
Type Aliases
- BoxStream
- SSE stream of raw lines sent to the client (
data: …\n\nper event).