pub struct ConversationStore { /* private fields */ }Expand description
Conversation storage operations.
Implementations
Sourceimpl ConversationStore
impl ConversationStore
Sourcepub async fn create(&self) -> StoreResult<ConversationData>
pub async fn create(&self) -> StoreResult<ConversationData>
Sourcepub async fn get_or_create(
&self,
conversation_id: &str,
) -> StoreResult<ConversationData>
pub async fn get_or_create( &self, conversation_id: &str, ) -> StoreResult<ConversationData>
Gets a conversation or creates it if it doesn’t exist.
Errors
Returns error if database query fails.
Sourcepub async fn get(&self, conversation_id: &str) -> StoreResult<ConversationData>
pub async fn get(&self, conversation_id: &str) -> StoreResult<ConversationData>
Sourcepub async fn rehydrate(
&self,
conversation_id: &str,
) -> StoreResult<Vec<InOutItem>>
pub async fn rehydrate( &self, conversation_id: &str, ) -> StoreResult<Vec<InOutItem>>
Rehydrates a conversation with all its items.
Errors
Returns an error if a stored item is missing its sequence number or if the database query fails.
Sourcepub async fn rehydrate_snapshot(
&self,
conversation_id: &str,
) -> StoreResult<ConversationSnapshot>
pub async fn rehydrate_snapshot( &self, conversation_id: &str, ) -> StoreResult<ConversationSnapshot>
Rehydrates a conversation with its items and storage version.
Errors
Returns an error if a stored item is missing its sequence number or if the database query fails.
Sourcepub async fn persist(
&self,
conversation_id: &str,
response_id: &str,
previous_response_id: Option<&str>,
new_items: Vec<InOutItem>,
metadata: &ResponseMetadata,
) -> StoreResult<()>
pub async fn persist( &self, conversation_id: &str, response_id: &str, previous_response_id: Option<&str>, new_items: Vec<InOutItem>, metadata: &ResponseMetadata, ) -> StoreResult<()>
Persists conversation turn with new items and response metadata.
Creates items in the conversation and stores the associated response record.
Errors
Returns StorageError if conversation not found or database operation fails.
Sourcepub async fn persist_if_version(
&self,
conversation_id: &str,
expected_version: ConversationVersion,
response_id: &str,
previous_response_id: Option<&str>,
new_items: Vec<InOutItem>,
metadata: &ResponseMetadata,
) -> StoreResult<()>
pub async fn persist_if_version( &self, conversation_id: &str, expected_version: ConversationVersion, response_id: &str, previous_response_id: Option<&str>, new_items: Vec<InOutItem>, metadata: &ResponseMetadata, ) -> StoreResult<()>
Persists a conversation turn only if its stored version still matches.
Errors
Returns StorageError if the conversation changed, was not found, or a database operation fails.