Database connection pooling and initialization.
Functions
- create_
pool - Creates a connection pool for the database.
- create_
pool_ with_ configs - Creates a connection pool with explicit database-specific tuning.
- create_
pool_ with_ schema - Creates a connection pool and initializes the database schema.
- create_
pool_ with_ schema_ and_ configs - Creates a connection pool with explicit database-specific tuning and initializes the database schema.
- create_
pool_ with_ schema_ and_ sqlite_ config - Creates a connection pool with explicit
SQLitetuning and initializes the database schema. - create_
pool_ with_ sqlite_ config - Creates a connection pool for the database with explicit
SQLitetuning.
Type Aliases
- DbPool
- Generic database pool type supporting
SQLite,PostgreSQL, andMySQL. - DbResult
- Convenience type alias for database operation results.
- DbTransaction
- Database transaction type for multi-statement operations.