Functions
- deserialize_
from_ str - Deserialize JSON string to any type.
- deserialize_
from_ str_ opt - Deserialize JSON string to any type, returning None on error.
- deserialize_
from_ str_ or_ default - Deserialize JSON string to any type with Default fallback.
- deserialize_
from_ string_ opt - Deserialize optional JSON String to any type, returning None on error or if None.
- deserialize_
from_ string_ opt_ or_ default - Deserialize optional JSON String to any type, returning default on error or if None.
- deserialize_
from_ value - Deserialize a
serde_json::ValueintoT. - deserialize_
from_ value_ opt - Deserialize a
serde_json::ValueintoT, returningNoneon type mismatch. - deserialize_
from_ value_ or_ custom_ default - Deserializes a
serde_json::Valueand passes it tothen, loggingmessageatdebuglevel and returningdefaultif deserialization fails. - serialize_
to_ string - Serialize any type to JSON string.
- serialize_
to_ value - Serialize any type to a
serde_json::Value. - serialize_
to_ value_ or_ custom_ default - Serializes
valueto aserde_json::Valueand passes it tothen, loggingmessageatdebuglevel and returningdefaultif serialization fails. - serialize_
to_ vec_ or_ default - Serialize any type to JSON bytes, returning an empty
Vecon error. - utcnow_
str - uuid7_
str