Module common

Module common 

Functions

deserialize_from_str
Deserialize JSON string to any type.
deserialize_from_str_opt
Deserialize JSON string to any type, returning None on error.
deserialize_from_str_or_default
Deserialize JSON string to any type with Default fallback.
deserialize_from_string_opt
Deserialize optional JSON String to any type, returning None on error or if None.
deserialize_from_string_opt_or_default
Deserialize optional JSON String to any type, returning default on error or if None.
deserialize_from_value
Deserialize a serde_json::Value into T.
deserialize_from_value_opt
Deserialize a serde_json::Value into T, returning None on type mismatch.
serialize_to_string
Serialize any type to JSON string.
serialize_to_vec_or_default
Serialize any type to JSON bytes, returning an empty Vec on error.
utcnow_str
uuid7_str